Struct caesar_core::relay::room::Room

source ·
pub struct Room {
    pub senders: Vec<Arc<Mutex<SplitSink<WebSocket, Message>>>>,
    pub size: usize,
}
Struct representing a room of WebSocket clients.

A Room contains a list of WebSocket senders and a room size. The senders are used to send messages to the WebSocket connections, while the room size represents the maximum number of clients allowed in the room.

Fields

senders: Vec<Arc<Mutex<SplitSink<WebSocket, Message>>>>

The list of WebSocket senders.

Each sender is used to send messages to a WebSocket connection.

size: usize

The size of the room.

This represents the maximum number of clients allowed in the room.

Implementations

source

impl Room

source

pub const DEFAULT_ROOM_SIZE: usize = 2usize

The default room size.

This is used as a fallback value when creating a new room.

source

pub fn new(size: usize) -> Room

Create a new room with the specified size.

Arguments
  • size - The size of the room.
Returns

A new Room instance.