Struct caesar_core::relay::room::Room
source · pub struct Room {
pub senders: Vec<Arc<Mutex<SplitSink<WebSocket, Message>>>>,
pub size: usize,
}Expand description
Struct representing a room of WebSocket clients.
A Room contains a list of WebSocket senders and a room size.
The senders are used to send messages to the WebSocket connections,
while the room size represents the maximum number of clients allowed in the room.
Fields
senders: Vec<Arc<Mutex<SplitSink<WebSocket, Message>>>>The list of WebSocket senders.
Each sender is used to send messages to a WebSocket connection.
size: usizeThe size of the room.
This represents the maximum number of clients allowed in the room.
Implementations